<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es-ES" sourcelanguage="en">
  <context>
    <name>AboutDialogBase</name>
    <message>
      <location filename="src/AboutDialogBase.ui" line="38"/>
      <source>About Synergy</source>
      <translation>Acerca de Synergy</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="140"/>
      <location filename="src/AboutDialogBase.ui" line="174"/>
      <source>Unknown</source>
      <translation>Desconocido</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="124"/>
      <source>Version:</source>
      <translation>Versión</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="53"/>
      <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2019 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Synergy GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</source>
      <translation>&lt;p&gt;
Aplicación para compartir ratón y teclado. Multiplataforma y de código abierto.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2019 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy se distribuye bajo la Licencia Pública General GNU (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy se basa en CosmoSynergy por Richard Lee y Adam Feder.&lt;br /&gt;
La interfaz de Synergy se basa en QSynergy por Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visite nuestro sitio Web para obtener ayuda e información (symless.com).
&lt;/p&gt;</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="167"/>
      <source>Build Date: </source>
      <translation>Fecha de compilación: </translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="194"/>
      <source>&amp;Ok</source>
      <translation>&amp;Ok</translation>
    </message>
  </context>
  <context>
    <name>ActionDialogBase</name>
    <message>
      <location filename="src/ActionDialogBase.ui" line="14"/>
      <source>Configure Action</source>
      <translation>Configurar Acción</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="20"/>
      <source>Choose the action to perform</source>
      <translation>Elige la acción a realizar</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="26"/>
      <source>Press a hotkey</source>
      <translation>Presiona una tecla de acceso directo</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="36"/>
      <source>Release a hotkey</source>
      <translation>Al levantar ó liberar el accedo directo</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="43"/>
      <source>Press and release a hotkey</source>
      <translation>Al pulsar y liberar el acceso directo</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="69"/>
      <source>only on these screens</source>
      <translation>sólo en estas pantallas</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="119"/>
      <source>Switch to screen</source>
      <translation>Cambiar a pantalla</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="150"/>
      <source>Switch in direction</source>
      <translation>Cambiar dirección</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="174"/>
      <source>left</source>
      <translation>izquierda</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="179"/>
      <source>right</source>
      <translation>derecha</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="184"/>
      <source>up</source>
      <translation>arriba</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="189"/>
      <source>down</source>
      <translation>abajo</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="201"/>
      <source>Lock cursor to screen</source>
      <translation>Bloquear cursor en pantalla</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="225"/>
      <source>toggle</source>
      <translation>alternar</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="230"/>
      <source>on</source>
      <translation>activado</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="235"/>
      <source>off</source>
      <translation>desactivado</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="247"/>
      <source>Restart server</source>
      <translation>Reiniciar el servidor</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="259"/>
      <source>This action is performed when</source>
      <translation>Esta acción se realiza cuando</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="265"/>
      <source>the hotkey is pressed</source>
      <translation>la tecla de acceso directo es presionada</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="275"/>
      <source>the hotkey is released</source>
      <translation>la tecla de acceso directo es soltada</translation>
    </message>
  </context>
  <context>
    <name>ActivationDialog</name>
    <message>
      <location filename="src/ActivationDialog.ui" line="14"/>
      <source>Activate Synergy</source>
      <translation>Activar Synergy</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="26"/>
      <source>Serial key</source>
      <translation>Clave de serie</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="33"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This can be found on your &lt;a href=&quot;https://symless.com/synergy/account-login&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;account&lt;/span&gt;&lt;/a&gt; page.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This can be found on your &lt;a href=&quot;https://symless.com/synergy/account-login&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;account&lt;/span&gt;&lt;/a&gt; page.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="49"/>
      <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="88"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="36"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;https://symless.com/synergy/trial/thanks?id=%1&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;https://symless.com/synergy/trial/thanks?id=%1&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="77"/>
      <source>An error occurred while trying to activate Synergy. Please contact the helpdesk, and provide the following information:

%1</source>
      <translation>Ocurrió un error mientras se trataba de activar Synergy. Póngase en contacto con el servicio técnico, y proporcione la siguiente información:

%1</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="86"/>
      <source>%1</source>
      <translation>%1</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="95"/>
      <source>Thanks for trying %1! %5

%2 day%3 of your trial remain%4</source>
      <translation type="unfinished">Thanks for trying %1! %5

%2 day%3 of your trial remain%4</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="114"/>
      <source>Thanks for activating %1!</source>
      <translation>¡Gracias por activar %1!</translation>
    </message>
  </context>
  <context>
    <name>AddClientDialog</name>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="20"/>
      <source>Dialog</source>
      <translation>Cuadro de diálogo</translation>
    </message>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="35"/>
      <source>TextLabel</source>
      <translation>TextLabel</translation>
    </message>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="83"/>
      <source>Ignore auto connect clients</source>
      <translation type="unfinished">Ignore auto connect clients</translation>
    </message>
  </context>
  <context>
    <name>CancelActivationDialog</name>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="14"/>
      <source>Cancel Activation</source>
      <translation>Cancelar Activación</translation>
    </message>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="20"/>
      <source>Are you sure?

If you don&apos;t activate Synergy you&apos;ll be missing out on some great features.</source>
      <translation type="unfinished">Are you sure?

If you don&apos;t activate Synergy you&apos;ll be missing out on some great features.</translation>
    </message>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="35"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/pricing?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/pricing?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
  </context>
  <context>
    <name>FailedLoginDialog</name>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="14"/>
      <source>Activation Error</source>
      <translation>Error de activación</translation>
    </message>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="42"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account/reset/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Forgotten your password?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account/reset/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Forgotten your password?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="58"/>
      <source>An error occurred while trying to activate Synergy. The Symless server returned the following error:

%1</source>
      <translation type="unfinished">An error occurred while trying to activate Synergy. The Symless server returned the following error:

%1</translation>
    </message>
  </context>
  <context>
    <name>HotkeyDialogBase</name>
    <message>
      <location filename="src/HotkeyDialogBase.ui" line="14"/>
      <source>Hotkey</source>
      <translation>Tecla de acceso directo</translation>
    </message>
    <message>
      <location filename="src/HotkeyDialogBase.ui" line="20"/>
      <source>Enter the specification for the hotkey:</source>
      <translation>Ingresa la especificación para la tecla de acceso directo:</translation>
    </message>
  </context>
  <context>
    <name>MainWindow</name>
    <message>
      <location filename="src/MainWindow.cpp" line="1000"/>
      <source>&amp;Start</source>
      <translation>&amp;Iniciar</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="284"/>
      <source>&amp;File</source>
      <translation>&amp;Archivo</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="285"/>
      <source>&amp;Edit</source>
      <translation>&amp;Edición</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="286"/>
      <source>&amp;Window</source>
      <translation>&amp;Ventana</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="287"/>
      <source>&amp;Help</source>
      <translation>&amp;Ayuda</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="432"/>
      <source>&lt;p&gt;Your version of Synergy is out of date. Version &lt;b&gt;%1&lt;/b&gt; is now available to &lt;a href=&quot;%2&quot;&gt;download&lt;/a&gt;.&lt;/p&gt;</source>
      <oldsource>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</oldsource>
      <translation>&lt;p&gt;Tú versión de Synergy es antigua. La versión &lt;b&gt;%1&lt;/b&gt; esta ahora disponible para &lt;a href=&quot;%2&quot;&gt;descargar&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="494"/>
      <source>Synergy is now connected. You can close the config window and Synergy will remain connected in the background.</source>
      <translation>Synergy está conectado. Puede cerrar la ventana de configuración y Synergy permanecerá conectado en segundo plano.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="546"/>
      <source>You are connecting to a server. Here is it&apos;s fingerprint:

%1

Compare this fingerprint to the one on your server&apos;s screen.If the two don&apos;t match exactly, then it&apos;s probably not the server you&apos;re expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</source>
      <translation type="unfinished">You are connecting to a server. Here is it&apos;s fingerprint:

%1

Compare this fingerprint to the one on your server&apos;s screen.If the two don&apos;t match exactly, then it&apos;s probably not the server you&apos;re expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="722"/>
      <source>Program can not be started</source>
      <translation>El programa no se puede iniciar</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="722"/>
      <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
      <translation>El ejecutable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;no se pudo iniciar exitósamente, aunque sí existe. Por favor, revisa si tienes permisos suficientes para ejecutar este programa.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="761"/>
      <source>Synergy client not found</source>
      <translation>No se encontró el cliente Synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="762"/>
      <source>The executable for the synergy client does not exist.</source>
      <translation>El ejecutable para el cliente Synergy no existe.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="789"/>
      <source>No server selected</source>
      <translation>Ningún servidor seleccionado</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="790"/>
      <source>No auto config server was selected, try manual mode instead.</source>
      <translation type="unfinished">No auto config server was selected, try manual mode instead.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="805"/>
      <source>Hostname is empty</source>
      <translation>Nombre de host está vacío</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="806"/>
      <source>Please fill in a hostname for the synergy client to connect to.</source>
      <translation>Por favor, ingresa un nombre de host al que se conectará el cliente Synergy.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="831"/>
      <source>Cannot write configuration file</source>
      <translation>No se puede escribir el archivo de configuración</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="831"/>
      <source>The temporary configuration file required to start synergy can not be written.</source>
      <translation>El archivo de configuración temporal necesario para iniciar Synergy no puede ser escrito.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="844"/>
      <source>Configuration filename invalid</source>
      <translation>Nombre de archivo de configuración inválido</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="845"/>
      <source>You have not filled in a valid configuration file for the synergy server. Do you want to browse for the configuration file now?</source>
      <translation>No has ingresado un archivo de configuración válido para el servidor Synergy. Queres buscar el archivo de configuración ahora?</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="873"/>
      <source>Synergy server not found</source>
      <translation>No se encontró el servidor Synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="874"/>
      <source>The executable for the synergy server does not exist.</source>
      <translation>El ejecutable para el servidor Synergy no existe.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="993"/>
      <source>&amp;Stop</source>
      <translation>&amp;Detener</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1016"/>
      <source>Synergy is waiting for clients</source>
      <translation>Synergy está esperando por clientes</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1023"/>
      <source>Synergy is connected (with %1)</source>
      <translation>Synergy está conectado (con %1)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1026"/>
      <source>Synergy is running (without TLS encryption)</source>
      <translation type="unfinished">Synergy is running (without TLS encryption)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1031"/>
      <source>Synergy is starting...</source>
      <translation>Synergy está iniciándose...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1034"/>
      <source>There was an error, retrying...</source>
      <translation>Hubo un error, reintentando...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1037"/>
      <source>Synergy is not running</source>
      <translation>Sinergy no se está ejecutando</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1354"/>
      <source>Please add the server (%1) to the grid.</source>
      <translation>Por favor, agregue el servidor (%1) en la grilla.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1360"/>
      <source>Please drag the new client screen (%1) to the desired position on the grid.</source>
      <translation>Por favor, arrastre la pantalla cliente (%1) a la posición deseada.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1093"/>
      <source>Unknown</source>
      <translation>Desconocido</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1247"/>
      <source>Browse for a synergys config file</source>
      <translation>Buscar un archivo de configuración Synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="545"/>
      <source>Security question</source>
      <translation>Pregunta de seguridad</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1260"/>
      <source>Save configuration as...</source>
      <translation>Guardar configuración como...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1264"/>
      <source>Save failed</source>
      <translation>No se guardó</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1264"/>
      <source>Could not save configuration to file.</source>
      <translation>No se pudo guardar la configuración en el archivo.</translation>
    </message>
  </context>
  <context>
    <name>MainWindowBase</name>
    <message>
      <location filename="src/MainWindowBase.ui" line="26"/>
      <source>Synergy</source>
      <translation>Synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="216"/>
      <source>Ser&amp;ver (share this computer&apos;s mouse and keyboard):</source>
      <translation>Ser&amp;ver (share this computer&apos;s mouse and keyboard):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="525"/>
      <location filename="src/MainWindowBase.ui" line="562"/>
      <source>&amp;Start</source>
      <translation>&amp;Iniciar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="307"/>
      <source>Use existing configuration:</source>
      <translation>Usar configuración existente:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="58"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;%1&lt;/span&gt; days of your Synergy Pro trial remain. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;%1&lt;/span&gt; days of your Synergy Pro trial remain. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="257"/>
      <source>SSL Fingerprint:</source>
      <translation>Huella digital SSL:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="316"/>
      <source>&amp;Configuration file:</source>
      <translation>&amp;Configuración:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="336"/>
      <source>&amp;Browse...</source>
      <translation>&amp;Buscar...</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="273"/>
      <source>Configure interactively:</source>
      <translation>Configurar interactivamente:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="285"/>
      <source>&amp;Configure Server...</source>
      <translation>&amp;Configurar Servidor...</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="369"/>
      <source>Client name:</source>
      <translation>Nombre del cliente:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="383"/>
      <source>&amp;Server:</source>
      <translation>&amp;Servidor:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="405"/>
      <source>Hostname or IP address of the server computer.</source>
      <translation>Nombre o dirección IP del servidor.</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="428"/>
      <source>Server:</source>
      <translation>Servidor:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="495"/>
      <source>Ready</source>
      <translation>Listo</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="438"/>
      <source>Log</source>
      <translation>Registro</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="518"/>
      <source>&amp;Apply</source>
      <translation>Aplicar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="233"/>
      <source>IP addresses:</source>
      <translation>Direcciones IP:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="354"/>
      <source>&amp;Client (use another computer&apos;s mouse and keyboard):</source>
      <translation>&amp;Client (use another computer&apos;s mouse and keyboard):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="535"/>
      <source>&amp;About Synergy...</source>
      <translation>&amp;Acerca de Synergy...</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="543"/>
      <source>Visit &amp;help site</source>
      <translation>Visitar sitio de &amp;ayuda</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="551"/>
      <source>&amp;Quit</source>
      <translation>&amp;Salir</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="554"/>
      <source>Quit</source>
      <translation>Salir</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="565"/>
      <source>Run</source>
      <translation>Ejecutar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="576"/>
      <source>S&amp;top</source>
      <translation>De&amp;tener</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="579"/>
      <source>Stop</source>
      <translation>Detener</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="587"/>
      <source>S&amp;how Status</source>
      <translation>&amp;Mostrar Estado</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="595"/>
      <source>&amp;Hide</source>
      <translation>&amp;Ocultar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="598"/>
      <source>Hide</source>
      <translation>Ocultar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="606"/>
      <source>&amp;Show</source>
      <translation>&amp;Mostrar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="609"/>
      <source>Show</source>
      <translation>Mostrar</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="617"/>
      <source>Save configuration &amp;as...</source>
      <translation>Gu&amp;ardar configuración como...</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="620"/>
      <source>Save the interactively generated server configuration to a file.</source>
      <translation>Guardar la configuración generada interactivamente en un archivo.</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="628"/>
      <source>Settings</source>
      <translation>Opciones</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="631"/>
      <source>Edit settings</source>
      <translation>Editar Opciones</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="639"/>
      <location filename="src/MainWindowBase.ui" line="642"/>
      <source>Activate</source>
      <translation>Activar</translation>
    </message>
  </context>
  <context>
    <name>NewScreenWidget</name>
    <message>
      <location filename="src/NewScreenWidget.cpp" line="32"/>
      <source>Unnamed</source>
      <translation>Sin nombre</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="src/MainWindow.cpp" line="62"/>
      <source>Synergy Configurations (*.sgc);;All files (*.*)</source>
      <translation>Configuraciones Synergy (*.sgc);;Todos los archivos (*.*)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="65"/>
      <source>Synergy Configurations (*.conf);;All files (*.*)</source>
      <translation>Configuraciones Synergy (*.conf);;Todos los archivos (*.*)</translation>
    </message>
  </context>
  <context>
    <name>ScreenSettingsDialog</name>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="67"/>
      <source>Screen name is empty</source>
      <translation>Nombre de pantalla está vacío</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="68"/>
      <source>The screen name cannot be empty. Please either fill in a name or cancel the dialog.</source>
      <translation>El nombre de la pantalla no puede estar vació. Por favor introduce un nombre o cancela este dialogo.</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="83"/>
      <source>Screen name matches alias</source>
      <translation>El nombre de la pantalla coincide con el alias</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="84"/>
      <source>The screen name cannot be the same as an alias. Please either remove the alias or change the screen name.</source>
      <translation>El nombre de la pantalla no puede ser el mismo que un alias. Elimina el alias o cambia el nombre de pantalla por favor.</translation>
    </message>
  </context>
  <context>
    <name>ScreenSettingsDialogBase</name>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="14"/>
      <source>Screen Settings</source>
      <translation>Opciones de Pantalla</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="22"/>
      <source>Screen &amp;name:</source>
      <translation>&amp;Nombre de Pantalla</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="42"/>
      <source>A&amp;liases</source>
      <translation>&amp;Alias</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="57"/>
      <source>&amp;Add</source>
      <translation>&amp;Agregar</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="74"/>
      <source>&amp;Remove</source>
      <translation>Elimina&amp;r</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="97"/>
      <source>&amp;Modifier keys</source>
      <translation>&amp;Modificar teclas</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="106"/>
      <source>&amp;Shift:</source>
      <translation>Mayú&amp;scula:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="117"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="164"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="211"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="258"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="305"/>
      <source>Shift</source>
      <translation>Mayúsculas</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="122"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="169"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="216"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="263"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="310"/>
      <source>Ctrl</source>
      <translation>Ctrl</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="127"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="174"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="221"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="268"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="315"/>
      <source>Alt</source>
      <translation>Alt</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="132"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="179"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="226"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="273"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="320"/>
      <source>Meta</source>
      <translation>Meta</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="137"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="184"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="231"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="278"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="325"/>
      <source>Super</source>
      <translation>Super</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="142"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="189"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="236"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="283"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="330"/>
      <source>None</source>
      <translation>Ninguno</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="150"/>
      <source>&amp;Ctrl:</source>
      <translation>&amp;Ctrl:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="197"/>
      <source>Al&amp;t:</source>
      <translation>Al&amp;t:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="244"/>
      <source>M&amp;eta:</source>
      <translation>M&amp;eta:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="291"/>
      <source>S&amp;uper:</source>
      <translation>S&amp;uper:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="358"/>
      <source>&amp;Dead corners</source>
      <translation>Esquinas &amp;Desactivadas</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="367"/>
      <source>Top-left</source>
      <translation>Arriba-Izquierda</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="374"/>
      <source>Top-right</source>
      <translation>Arriba-Derecha</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="381"/>
      <source>Bottom-left</source>
      <translation>Abajo-Izquierda</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="388"/>
      <source>Bottom-right</source>
      <translation>Abajo-Derecha</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="397"/>
      <source>Corner Si&amp;ze:</source>
      <translation>&amp;Tamaño de Esquina:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="428"/>
      <source>&amp;Fixes</source>
      <translation>&amp;Reparaciones</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="437"/>
      <source>Fix CAPS LOCK key</source>
      <translation>Reparar tecla CAPS LOCK (BLOQ MAYÚS)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="444"/>
      <source>Fix NUM LOCK key</source>
      <translation>Reparar tecla NUM LOCK (BLOQ NUM)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="451"/>
      <source>Fix SCROLL LOCK key</source>
      <translation>Reparar tecla SCROLL LOCK (BLOQ DESPL)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="458"/>
      <source>Fix XTest for Xinerama</source>
      <translation>Reparar XTest para Xinerama</translation>
    </message>
  </context>
  <context>
    <name>ScreenSetupModel</name>
    <message>
      <location filename="src/ScreenSetupModel.cpp" line="51"/>
      <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
      <translation>&lt;center&gt;Pantalla: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Haz doble clic para editar opciones&lt;br&gt;Arrastra la pantalla a la papelera para borrarla</translation>
    </message>
  </context>
  <context>
    <name>ServerConfigDialog</name>
    <message>
      <location filename="src/ServerConfigDialog.cpp" line="83"/>
      <source>Configure server</source>
      <translation>Configurar servidor</translation>
    </message>
  </context>
  <context>
    <name>ServerConfigDialogBase</name>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="14"/>
      <source>Server Configuration</source>
      <translation>Configuración de Servidor</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="24"/>
      <source>Screens and links</source>
      <translation>Pantallas y enlaces</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="35"/>
      <source>Drag a screen from the grid to the trashcan to remove it.</source>
      <translation>Mueve una pantalla de la rejilla a la papelera para eliminarla.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="60"/>
      <source>Configure the layout of your synergy server configuration.</source>
      <translation>Elige el diseño de rejilla para la configuración de tu servidor Synergy.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="73"/>
      <source>Drag this button to the grid to add a new screen.</source>
      <translation>Mueve este botón a la rejilla para añadir una nueva pantalla.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="128"/>
      <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
      <translation>Arrastra nuevas pantallas hacia la rejilla o mueve las ya existentes.
Mueve una pantalla a la papelera para eliminarla.
Haz doble click sobre una pantalla para modificar sus ajustes.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="157"/>
      <source>Hotkeys</source>
      <translation>Teclas de acceso directo</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="163"/>
      <source>&amp;Hotkeys</source>
      <translation>&amp;Teclas de acceso directo</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="175"/>
      <source>&amp;New</source>
      <translation>&amp;Nueva</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="185"/>
      <source>&amp;Edit</source>
      <translation>&amp;Edición</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="195"/>
      <source>&amp;Remove</source>
      <translation>Elimina&amp;r</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="218"/>
      <source>A&amp;ctions</source>
      <translation>&amp;Acciones</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="230"/>
      <source>Ne&amp;w</source>
      <translation>&amp;Nueva</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="240"/>
      <source>E&amp;dit</source>
      <translation>&amp;Editar</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="250"/>
      <source>Re&amp;move</source>
      <translation>&amp;Borrar</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="274"/>
      <source>Advanced server settings</source>
      <translation>Opciones Avanzadas de Servidor</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="280"/>
      <source>&amp;Switch</source>
      <translation>&amp;Cambiar</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="291"/>
      <source>Switch &amp;after waiting</source>
      <translation>Cambiar &amp;al esperar</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="330"/>
      <location filename="src/ServerConfigDialogBase.ui" line="383"/>
      <location filename="src/ServerConfigDialogBase.ui" line="552"/>
      <source>ms</source>
      <translation>ms</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="344"/>
      <source>Switch on double &amp;tap within</source>
      <translation>Cambiar doble toque en</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="408"/>
      <source>&amp;Options</source>
      <translation>Opciones</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="416"/>
      <source>Enable clipboard sharing</source>
      <translation>Habilitar compartir portapapeles</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="452"/>
      <source>MB</source>
      <translation>MB</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="461"/>
      <source>Enable drag and drop file transfers</source>
      <translation>Habilitar transferencias de archivos vía arrastrar y soltar</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="513"/>
      <source>&amp;Check clients every</source>
      <translation>Revisar &amp;clientes cada</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="481"/>
      <source>Use &amp;relative mouse moves</source>
      <translation>&amp;Sar movimientos &amp;relativos del mouse</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="564"/>
      <source>S&amp;ynchronize screen savers</source>
      <translation>&amp;Sincronizar protectores de pantalla</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="471"/>
      <source>Don&apos;t take &amp;foreground window on Windows servers</source>
      <translation>No tomar la ventana de primer plano en servidores Windows</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="501"/>
      <source>Ignore auto config clients</source>
      <translation>Ignorar la configuración automatica de clientes</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="571"/>
      <source>Disable lock to screen</source>
      <translation>Desactivar la pantalla de bloqueo</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="581"/>
      <source>&amp;Dead corners</source>
      <translation>Esquinas &amp;Desactivadas</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="590"/>
      <source>To&amp;p-left</source>
      <translation>&amp;Arriba-Izquierda</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="597"/>
      <source>Top-rig&amp;ht</source>
      <translation>&amp;Arriba-Derec&amp;ha</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="604"/>
      <source>&amp;Bottom-left</source>
      <translation>&amp;Bajo-Izquierda</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="611"/>
      <source>Bottom-ri&amp;ght</source>
      <translation>&amp;Abajo-Derecha</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="633"/>
      <source>Cor&amp;ner Size:</source>
      <translation>&amp;Tamaño de Esqui&amp;na:</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialog</name>
    <message>
      <location filename="src/SettingsDialog.cpp" line="184"/>
      <source>Save log file to...</source>
      <translation>Guardar archivo de registro en...</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialogBase</name>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="14"/>
      <source>Settings</source>
      <translation>Opciones</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="21"/>
      <source>&amp;Settings Scope</source>
      <translation>&amp;Alcance de las preferencias</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="27"/>
      <source>System</source>
      <translation>Sistema</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="37"/>
      <source>User</source>
      <translation>Usuario</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="59"/>
      <source>Sc&amp;reen name:</source>
      <translation>&amp;Nomb&amp;re de Pantalla:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="76"/>
      <source>P&amp;ort:</source>
      <translation>Puert&amp;o:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="105"/>
      <source>&amp;Interface:</source>
      <translation>&amp;Interfaz:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="147"/>
      <source>Specify when the Synergy service should run at an elevated privilege level</source>
      <translation>Especifique cuándo el servicio de Synergy debe ejecutarse con privilegios elevados</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="154"/>
      <source>As Needed</source>
      <translation>En tanto necesario</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="159"/>
      <source>Always</source>
      <translation>Siempre</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="164"/>
      <source>Never</source>
      <translation>Nunca</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="172"/>
      <source>Elevate</source>
      <translation>Elevar</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="186"/>
      <source>Minimize to System &amp;Tray</source>
      <translation>Minimizar a la bandeja del &amp;sistema</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="221"/>
      <source>&amp;Network</source>
      <translation>&amp;Red</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="253"/>
      <source>Enable &amp;TLS Encryption</source>
      <translation>Habilitar cifrado &amp;TLS</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="263"/>
      <source>Enable Auto Config</source>
      <translation>Activar configuración automática</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="270"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Install Bonjour&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Instalar Bonjour&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="280"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account?source=gui&amp;amp;intent=upgrade&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Upgrade to Pro&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account?source=gui&amp;intent=upgrade&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Actualizar a Pro&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="179"/>
      <source>&amp;Hide on startup</source>
      <translation>&amp;Ocultar al iniciar</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="320"/>
      <source>Logging</source>
      <translation>Registro</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="338"/>
      <source>&amp;Logging level:</source>
      <translation>Nive&amp;l de Registro:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="372"/>
      <source>Log to file:</source>
      <translation>Guardar registro en archivo:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="389"/>
      <source>Browse...</source>
      <translation>Examinar...</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="134"/>
      <source>&amp;Language:</source>
      <translation>Idioma:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="47"/>
      <source>&amp;Miscellaneous</source>
      <translation>Misceláneos
</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="349"/>
      <source>Info</source>
      <translation>Información</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="354"/>
      <source>Debug</source>
      <translation>Depuración</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="359"/>
      <source>Debug1</source>
      <translation>Depuración1</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="364"/>
      <source>Debug2</source>
      <translation>Depuración2</translation>
    </message>
  </context>
  <context>
    <name>SetupWizard</name>
    <message>
      <location filename="src/SetupWizard.cpp" line="65"/>
      <source>Setup Synergy</source>
      <translation>Configurar Synergy</translation>
    </message>
    <message>
      <location filename="src/SetupWizard.cpp" line="75"/>
      <source>Please select an option.</source>
      <translation>Elige una opción, por favor.</translation>
    </message>
  </context>
  <context>
    <name>SetupWizardBase</name>
    <message>
      <location filename="src/SetupWizardBase.ui" line="26"/>
      <source>Setup Synergy</source>
      <translation>Configurar Synergy</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="30"/>
      <source>Welcome</source>
      <translation>Bienvenido</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="39"/>
      <source>Thanks for installing Synergy!</source>
      <translation>¡Gracias por instalar Synergy!</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="114"/>
      <source>Synergy lets you easily share your mouse and keyboard between multiple computers on your desk, and it&apos;s Free and Open Source. Just move your mouse off the edge of one computer&apos;s screen on to another. You can even share all of your clipboards. All you need is a network connection. Synergy is cross-platform (works on Windows, Mac OS X and Linux).</source>
      <translation>Synergy te permite compartir fácilmente tu mouse y teclado entre múltiples computadores en tu escritorio, es Gratis y es de Código Abierto. Solo mueve tu mouse hacia los bordes de la pantalla de uno de los computadores hacia otro. Puedes incluso compartir tu portapapeles. Todo lo que necesitas es una conexión de red. Synergy es multiplataforma (funciona en Windows, Mac OS X y Linux).</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="159"/>
      <source>My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer&apos;s screen. There can only be one server in your setup.</source>
      <translation>Mi ratón y teclado principales están conectados a este ordenador. Esto le permitirá mover el puntero hacia otra pantalla en otro ordenador. Puede haber sólo un servidor en su configuración.</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="204"/>
      <source>You have already set up a server. This computer will be controlled using the server&apos;s mouse and keyboard. There can be many clients in your setup.</source>
      <translation>Ya ha configurado un servidor. Este ordenador será controlado utilizando el ratón y teclado del servidor. Se pueden agregar varios clientes en su configuración.</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="146"/>
      <source>&amp;Server (share this computer&apos;s mouse and keyboard)</source>
      <translation>&amp;Servidor (compartir el teclado y ratón de este ordenador)</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="191"/>
      <source>&amp;Client (use another computer&apos;s mouse and keyboard)</source>
      <translation>&amp;Cliente (usar el teclado y ratón de otro ordenador)</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="131"/>
      <source>Server or Client?</source>
      <translation>¿Servidor o Cliente?</translation>
    </message>
  </context>
  <context>
    <name>SslCertificate</name>
    <message>
      <location filename="src/SslCertificate.cpp" line="46"/>
      <source>Failed to get profile directory.</source>
      <translation>No fue posible encontrar el directorio de perfil.</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="148"/>
      <source>SSL certificate generated.</source>
      <translation>Certificado SSL generado.</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="178"/>
      <source>SSL fingerprint generated.</source>
      <translation>Se generó la huella digital SSL.</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="181"/>
      <source>Failed to find SSL fingerprint.</source>
      <translation>No se pudo encontrar la huella SSL.</translation>
    </message>
  </context>
  <context>
    <name>VersionChecker</name>
    <message>
      <location filename="src/VersionChecker.cpp" line="145"/>
      <source>Unknown</source>
      <translation>Desconocido</translation>
    </message>
  </context>
  <context>
    <name>ZeroconfService</name>
    <message>
      <location filename="src/ZeroconfService.cpp" line="82"/>
      <source>zeroconf server detected: %1</source>
      <translation>se detectó un servidor zeroconf: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="91"/>
      <source>zeroconf client detected: %1</source>
      <translation>se detectó un cliente zeroconf: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="100"/>
      <location filename="src/ZeroconfService.cpp" line="132"/>
      <location filename="src/ZeroconfService.cpp" line="143"/>
      <source>Synergy Auto Config</source>
      <translation>Configuración automática Sinergy</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="133"/>
      <source>Unable to start zeroconf: %1.</source>
      <translation>No fue posible iniciar zeroconf: %1.</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="101"/>
      <source>Error code: %1.</source>
      <translation>Código de error: %1.</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="144"/>
      <source>Failed to get local IP address. Please manually type in server address on your clients</source>
      <translation>No fue posible obtener la IP local. Por favor, ingrese la IP manualmente en sus clientes.</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="150"/>
      <location filename="src/ZeroconfService.cpp" line="157"/>
      <source>%1</source>
      <translation>%1</translation>
    </message>
  </context>
</TS>
